============
Bag of Words
============

.. automodule:: orangecontrib.text.vectorization.bagofwords


.. autoclass:: orangecontrib.text.vectorization.bagofwords.BowVectorizer
   :members: transform
   :special-members: __init__

